@@ -1,10 +1,10 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.13
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2020 Frank Pagliughi <fpagliughi@mindspring.com>
-# All rights reserved. 
-# 
-# This program and the accompanying materials are made available 
+# All rights reserved.
+#
+# This program and the accompanying materials are made available
 # under the terms of the Eclipse Distribution License v1.0
 # which accompanies this distribution.
 #
@@ -16,6 +16,8 @@
 #
 
 # This shows an example of an MQTTv5 Remote Procedure Call (RPC) client.
+# You should run the server_rpc_math.py before.
+
 
 import json
 import sys
@@ -33,14 +35,14 @@ reply_to = ""
 # This correlates the outbound request with the returned reply
 corr_id = b"1"
 
-# This is sent in the message callback when we get the respone
+# This is sent in the message callback when we get the response
 reply = None
 
 # The MQTTv5 callback takes the additional 'props' parameter.
-def on_connect(mqttc, userdata, flags, rc, props):
+def on_connect(mqttc, userdata, flags, reason_code, props):
     global client_id, reply_to
 
-    print("Connected: '"+str(flags)+"', '"+str(rc)+"', '"+str(props))
+    print(f"Connected: '{flags}', '{reason_code}',  '{props}'")
     if hasattr(props, 'AssignedClientIdentifier'):
         client_id = props.AssignedClientIdentifier
     reply_to = "replies/math/" + client_id
@@ -65,11 +67,11 @@ if len(sys.argv) < 3:
     print("USAGE: client_rpc_math.py [add|mult] n1 n2 ...")
     sys.exit(1)
 
-mqttc = mqtt.Client(client_id="", protocol=mqtt.MQTTv5)
+mqttc = mqtt.Client(mqtt.CallbackAPIVersion.VERSION2, client_id="", protocol=mqtt.MQTTv5)
 mqttc.on_message = on_message
 mqttc.on_connect = on_connect
 
-mqttc.connect(host='localhost', clean_start=True)
+mqttc.connect(host="mqtt.eclipseprojects.io", clean_start=True)
 mqttc.loop_start()
 
 # Wait for connection to set `client_id`, etc.
@@ -96,7 +98,7 @@ for s in sys.argv[2:]:
     args.append(float(s))
 
 # Send the request
-topic = "requests/math/" + func 
+topic = "requests/math/" + func
 payload = json.dumps(args)
 mqttc.publish(topic, payload, qos=1, properties=props)
 
