@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.11
+#!/usr/local/bin/python3.13
 # -*- coding: utf-8 -*-
 
 # Copyright (c) 2010-2013 Roger Light <roger@atchoo.org>
@@ -22,20 +22,16 @@ import context  # Ensures paho is in PYTHONPATH
 import paho.mqtt.client as mqtt
 
 
-def on_connect(mqttc, obj, flags, rc):
-    print("rc: " + str(rc))
+def on_connect(mqttc, obj, flags, reason_code, properties):
+    print("reason_code: " + str(reason_code))
 
 
 def on_message(mqttc, obj, msg):
     print(msg.topic + " " + str(msg.qos) + " " + str(msg.payload))
 
 
-def on_publish(mqttc, obj, mid):
-    print("mid: " + str(mid))
-
-
-def on_subscribe(mqttc, obj, mid, granted_qos):
-    print("Subscribed: " + str(mid) + " " + str(granted_qos))
+def on_subscribe(mqttc, obj, mid, reason_code_list, properties):
+    print("Subscribed: " + str(mid) + " " + str(reason_code_list))
 
 
 def on_log(mqttc, obj, level, string):
@@ -46,14 +42,13 @@ def on_log(mqttc, obj, level, string):
 # mqttc = mqtt.Client("client-id")
 # but note that the client id must be unique on the broker. Leaving the client
 # id parameter empty will generate a random id for you.
-mqttc = mqtt.Client()
+mqttc = mqtt.Client(mqtt.CallbackAPIVersion.VERSION2)
 mqttc.on_message = on_message
 mqttc.on_connect = on_connect
-mqttc.on_publish = on_publish
 mqttc.on_subscribe = on_subscribe
 # Uncomment to enable debug messages
 # mqttc.on_log = on_log
 mqttc.connect("mqtt.eclipseprojects.io", 1883, 60)
-mqttc.subscribe("$SYS/#", 0)
+mqttc.subscribe("$SYS/#")
 
 mqttc.loop_forever()
